@@ -3,15 +3,12 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use Carp;
 use Exporter;
 use File::Find::Rule;
-use File::Temp qw(tempfile);
-
-our @ISA = qw(Exporter);
-our @EXPORT_OK = qw (read pread write pwrite);
+use File::Temp;
 
 sub new {
     return bless {}, shift;
@@ -41,14 +38,14 @@ sub read {
 
     $self->recsep($file);
 
-    my $fh = $self->_open($file);
+    my $fh;
 
     if (! wantarray){
-        my $handle = $self->_handle($file);
-        return $handle;
+        $fh = $self->_handle($file);
+        return $fh;
     }
     else {
-
+        $fh = $self->_open($file); 
         my @contents = <$fh>;
         close $fh or croak "read() can't close file $file!: $!";
 
@@ -86,29 +83,29 @@ sub write {
 
     my $wfh = $self->_open($file, 'w');
 
+    $recsep = defined $recsep ? $recsep : $self->{recsep};
+
     # is contents a fh?
 
-    if (ref($contents) eq 'GLOB'){
-        my @temp = <$contents>;
-        close $contents;
-        $contents = \@temp;
-    }
+    if (ref($contents) eq 'GLOB' || ref($contents) eq 'File::Temp'){
+        seek $contents, 0, 0;
 
-    for (@$contents){
-        s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}//g;
-
-        if ($recsep){
+        while (<$contents>){
+            s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}//g;
             print $wfh $_ . $recsep;
         }
-        else {
-            print $wfh $_ . $self->{recsep};
+        close $contents;
+    }
+    else {
+        for (@$contents){
+            s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}//g;
+            print $wfh $_ . $recsep;
         }
     }
 
+    close $wfh;
     $self->{is_read} = 0;
     
-    close $wfh or croak "write() can't close file $file: $!";
-
     return 1;
 }
 sub splice {
@@ -121,6 +118,7 @@ sub splice {
     my $insert = $self->{insert};
     my $find = $self->{find};
     my $line = $self->{line};
+    my $limit = defined $self->{limit} ? $self->{limit} : 1;
 
     if (! $insert){
         croak "splice() requires insert => [aref] param";
@@ -136,11 +134,16 @@ sub splice {
         $find = qr{$find};
 
         my $i = 0;
+        my $inserts = 0;
+
         for (@contents){
             $i++;
             if (/$find/){
+                $inserts++;
                 splice @contents, $i, 0, @$insert;
-                last;
+                if ($limit){
+                    last if $inserts == $limit;
+                }
             }
         }
     }
@@ -194,21 +197,16 @@ sub recsep {
     my $hex = shift if @_;
 
     my $fh;
-    my @contents;
 
     eval {
         $fh = $self->_open($file);
-
-        binmode $fh, ':raw';
-
-        croak "recsep() couldn't acquire file handle" if $@;
-
-        @contents = <$fh>;
     };
 
+    croak "recsep() couldn't acquire file handle for $file" if $@;
+
     my $recsep;
 
-    if ($@ || ! $contents[0]){
+    if ($@ || ! <$fh>){
 
         # we've got an empty file...
         # we'll set recsep to the local platform's
@@ -248,7 +246,7 @@ sub platform_recsep {
     my $self = shift;
     my $hex = shift if @_;
 
-    my $file = $self->_temp_file;
+    my $file = $self->_temp_filename;
 
     # this is for checking to see if we've cleaned up
     # in DESTROY
@@ -284,6 +282,13 @@ sub platform_recsep {
         return $self->{platform_recsep};
     }
 }
+sub tempfile {
+
+    my $self = shift;
+    
+    my $wfh = File::Temp->new(UNLINK => 1);
+    return $wfh;
+}
 sub _config {
 
     my $self = shift;
@@ -292,15 +297,15 @@ sub _config {
     $self->{custom_recsep} = $p{recsep};
     delete $p{recsep};
 
-    delete $self->{testing};
-    delete $self->{copy};
-    delete $self->{types};
-    delete $self->{list};
-    delete $self->{maxdepth};
-    delete $self->{insert};
-    delete $self->{line};
-    delete $self->{find};
+    my @params = qw(
+                    testing copy types list maxdepth
+                    insert line find limit
+                   );
 
+    for (@params){
+        delete $self->{$_};
+    }
+    
     for (keys %p){
         $self->{$_} = $p{$_};
     }
@@ -309,31 +314,40 @@ sub _handle {
 
     my $self = shift;
     my $file = shift;
+   
+    my $fh;
 
-    my $fh = $self->_open($file);
-    my $temp_wfh = File::Temp->new(UNLINK => 1);
-    binmode $temp_wfh, ':raw';
-    
-    my $temp_filename = $temp_wfh->filename;
+    if ($self->recsep($file, 'hex') ne $self->platform_recsep('hex')){ 
+        
+        $fh = $self->_open($file);
+        my $temp_wfh = $self->tempfile;
+        binmode $temp_wfh, ':raw';
 
-    # we'll check these in DESTROY to make sure we've
-    # cleaned up appropriately
+        my $temp_filename = $temp_wfh->filename;
 
-    push @{ $self->{temp_files} }, $temp_filename;
+        # we'll check these in DESTROY to make sure we've
+        # cleaned up appropriately
 
-    $self->platform_recsep;
+        push @{ $self->{temp_files} }, $temp_filename;
 
-    for (<$fh>){
-        s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}/$self->{platform_recsep}/;
-        print $temp_wfh $_;
+        my $platform_recsep = $self->platform_recsep;
+
+        while (<$fh>){
+            s/[\n\x{0B}\f\r\x{85}]{1,2}|[{utf8}2028-{utf8}2029]]{1,2}/$platform_recsep/g;
+            print $temp_wfh $_;
+        }
+        
+        close $fh or die "can't close file $file: $!";
+        close $temp_wfh or die "can't close file $temp_filename: $!";
+
+        my $ret_fh = $self->_open($temp_filename);
+        
+        return $ret_fh;
+    }
+    else {
+        $fh = $self->_open($file);
+        return $fh;
     }
-
-    close $fh or die "can't close file $file: $!";
-    close $temp_wfh or die "can't close file $temp_filename: $!";
-
-    my $ret_fh = $self->_open($temp_filename);
-    
-    return $ret_fh;
 }
 sub _open {
 
@@ -356,7 +370,7 @@ sub _open {
 
     return $fh;
 }
-sub _temp_file {
+sub _temp_filename {
 
     my $self = shift;
     
@@ -365,7 +379,7 @@ sub _temp_file {
     my $file = $temp_fh->filename;
 
     close $temp_fh
-     or croak "_temp_file() can't close the $file temp file: $!";
+     or croak "_temp_filename() can't close the $file temp file: $!";
 
     return $file;
 }
@@ -399,11 +413,25 @@ File::Edit::Portable - Read and write files while keeping the original line-endi
     use File::Edit::Portable;
     my $rw = File::Edit::Portable->new;
 
+    # edit file in a loop, and re-write it with its original line endings
+
+    my $fh = $rw->read('file.txt');
+    my $wfh = $rw->tempfile;
+
+    while (<$fh>){
+        ...
+        print $wfh $_;
+    }
+
+    $rw->write(contents => $wfh);
+
     # read a file, replacing original file's line endings with
     # that of the local platform's default
 
     my $fh = $rw->read('file.txt');
-    # or
+    
+    # get an array of the file's contents, with line endings stripped off
+
     my @contents = $rw->read('file.txt');
 
     # write out a file using original file's record separator
@@ -482,6 +510,8 @@ C<line =E<gt> 23>: Optional - Merge the contents on the line following the one s
 
 C<find =E<gt> 'search term'>: Optional - Merge the contents into the file on the line following the first find of the search term. The search term is put into C<qr>, so single quotes are recommended, and all regex patterns are honoured.
 
+C<limit =E<gt> Integer>: Optional: When splicing with the 'find' param, set this to the number of finds to insert after. Default is stop after the first find. Set to 0 will insert after all finds.
+
 NOTE: Although both are optional, at least one of C<line> or C<find> must be sent in.
 
 Returns an array of the modified file contents.  
@@ -518,6 +548,10 @@ If the optional string parameter 'hex' is sent in, we'll return the record separ
 
 Returns the the current platform's (OS) record separator. If the optional string value "hex" is sent in, we'll return the recsep in hex format. Otherwise, we'll return it in as-is string format.
 
+=head2 C<tempfile>
+
+Returns a file handle in write mode to an empty temp file.
+
 
 =head1 AUTHOR
 
